@@ -23,6 +23,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
+from __future__ import print_function
 from smartcard.CardType import CardType
 from smartcard.CardRequest import CardRequest
 from smartcard.util import toHexString
@@ -44,11 +45,11 @@ cardservice = cardrequest.waitforcard()
 
 # connect and print atr and reader
 cardservice.connection.connect()
-print toHexString(cardservice.connection.getATR())
-print cardservice.connection.getReader()
+print(toHexString(cardservice.connection.getATR()))
+print(cardservice.connection.getReader())
 
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
