@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 from smartcard.CardType import AnyCardType
 from smartcard.CardRequest import CardRequest
 from smartcard.CardConnectionObserver import ConsoleCardConnectionObserver
@@ -43,8 +44,8 @@ DF_TELECOM = [0x7F, 0x10]
 
 if __name__ == '__main__':
 
-    print 'Insert a card within 10 seconds'
-    print 'Cards without a DF_TELECOM will except'
+    print('Insert a card within 10 seconds')
+    print('Cards without a DF_TELECOM will except')
 
     # request any card type
     cardtype = AnyCardType()
@@ -77,12 +78,12 @@ if __name__ == '__main__':
             apdu = GET_RESPONSE + [sw2]
             response, sw1, sw2 = cardservice.connection.transmit(apdu)
 
-    except SWException, e:
-        print str(e)
+    except SWException as e:
+        print(str(e))
 
     cardservice.connection.disconnect()
 
     import sys
     if 'win32' == sys.platform:
-        print 'press Enter to continue'
+        print('press Enter to continue')
         sys.stdin.read(1)
