@@ -26,16 +26,17 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 from smartcard.scard import *
 import smartcard.util
 
-try:
+if __name__ == '__main__':
     hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
     if hresult != SCARD_S_SUCCESS:
         raise error(
             'Failed to establish context: ' + \
             SCardGetErrorMessage(hresult))
-    print 'Context established!'
+    print('Context established!')
 
     try:
         hresult, readers = SCardListReaders(hcontext, [])
@@ -45,51 +46,48 @@ try:
                 SCardGetErrorMessage(hresult))
         if len(readers) < 1:
             raise Exception('No smart card readers')
-        print 'PCSC Readers:', readers
+        print('PCSC Readers:', readers)
 
         for reader in readers:
-            print 'Trying to retreive ATR of card in', reader
+            print('Trying to retreive ATR of card in', reader)
 
             hresult, hcard, dwActiveProtocol = SCardConnect(
                 hcontext,
                 reader,
                 SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
             if hresult != SCARD_S_SUCCESS:
-                print 'Unable to connect: ' + SCardGetErrorMessage(hresult)
+                print('Unable to connect: ' + SCardGetErrorMessage(hresult))
             else:
 
-                print 'Connected with active protocol', dwActiveProtocol
+                print('Connected with active protocol', dwActiveProtocol)
 
                 try:
                     hresult, reader, state, protocol, atr = SCardStatus(hcard)
                     if hresult != SCARD_S_SUCCESS:
-                        print 'failed to get status: ' + \
-                              SCardGetErrorMessage(hresult)
-                    print 'Reader:', reader
-                    print 'State:', hex(state)
-                    print 'Protocol:', protocol
-                    print 'ATR:', smartcard.util.toHexString(
+                        print('failed to get status: ' + \
+                              SCardGetErrorMessage(hresult))
+                    print('Reader:', reader)
+                    print('State:', hex(state))
+                    print('Protocol:', protocol)
+                    print('ATR:', smartcard.util.toHexString(
                                         atr,
-                                        smartcard.util.HEX)
+                                        smartcard.util.HEX))
 
                 finally:
                     hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
                     if hresult != SCARD_S_SUCCESS:
-                        print 'Failed to disconnect: ' + \
-                            SCardGetErrorMessage(hresult)
-                    print 'Disconnected'
+                        print('Failed to disconnect: ' + \
+                            SCardGetErrorMessage(hresult))
+                    print('Disconnected')
 
     finally:
         hresult = SCardReleaseContext(hcontext)
         if hresult != SCARD_S_SUCCESS:
             raise error('Failed to release context: ' + \
                             SCardGetErrorMessage(hresult))
-        print 'Released context.'
-
-except Exception, e:
-    print e
+        print('Released context.')
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
