@@ -26,6 +26,7 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 import platform
 from smartcard.scard import *
 import smartcard.guid
@@ -42,13 +43,13 @@ if 'winscard' == resourceManager:
     znewcardSecGuid = \
         smartcard.guid.strToGUID('{EB7F69EA-BA20-47d0-8C50-11CFDEB63BBE}')
 
-    try:
+    def main():
         hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
         if hresult != SCARD_S_SUCCESS:
             raise scard.error(
                 'Failed to establish context: ' + \
                 SCardGetErrorMessage(hresult))
-        print 'Context established!'
+        print('Context established!')
 
         try:
 
@@ -66,11 +67,11 @@ if 'winscard' == resourceManager:
                 raise scard.error(
                     'Failed to list interfaces: ' + \
                     SCardGetErrorMessage(hresult))
-            print 'Interfaces for ', expectedCard, ':', interfaces
+            print('Interfaces for ', expectedCard, ':', interfaces)
 
             # introduce a card (forget first in case it is already present)
             hresult = SCardForgetCardType(hcontext, znewcardName)
-            print 'Introducing card ' + znewcardName
+            print('Introducing card ' + znewcardName)
             hresult = SCardIntroduceCardType(
                 hcontext,
                 znewcardName,
@@ -90,10 +91,10 @@ if 'winscard' == resourceManager:
                     'Failed to list interfaces: ' + \
                     SCardGetErrorMessage(hresult))
             for i in interfaces:
-                print 'Interface for ' + znewcardName + ' :', \
-                      smartcard.guid.GUIDToStr(i)
+                print('Interface for ' + znewcardName + ' :', \
+                      smartcard.guid.GUIDToStr(i))
 
-            print 'Forgeting card ' + znewcardName
+            print('Forgeting card ' + znewcardName)
             hresult = SCardForgetCardType(hcontext, znewcardName)
             if hresult != SCARD_S_SUCCESS:
                 raise error(
@@ -106,17 +107,14 @@ if 'winscard' == resourceManager:
                 raise error(
                     'Failed to release context: ' + \
                     SCardGetErrorMessage(hresult))
-            print 'Released context.'
-
-    except error:
-        import sys
-        print sys.exc_info()[0], ':', sys.exc_info()[1]
+            print('Released context.')
+    main()
 
 elif 'pcsclite' == resourceManager:
-    print 'SCardListInterfaces not supported by pcsc lite'
+    print('SCardListInterfaces not supported by pcsc lite')
 
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
