@@ -25,6 +25,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
+from __future__ import print_function
 from smartcard.CardType import AnyCardType
 from smartcard.CardRequest import CardRequest
 from smartcard.CardConnectionObserver import ConsoleCardConnectionObserver
@@ -40,7 +41,7 @@ cardtype = AnyCardType()
 
 try:
     # request card insertion
-    print 'insert a card (SIM card if possible) within 10s'
+    print('insert a card (SIM card if possible) within 10s')
     cardrequest = CardRequest(timeout=10, cardType=cardtype)
     cardservice = cardrequest.waitforcard()
 
@@ -60,16 +61,12 @@ try:
         response, sw1, sw2 = cardservice.connection.transmit(apdu)
 
     else:
-        print 'no DF_TELECOM'
+        print('no DF_TELECOM')
 
 except CardRequestTimeoutException:
-    print 'time-out: no card inserted during last 10s'
-
-except:
-    import sys
-    print sys.exc_info()[1]
+    print('time-out: no card inserted during last 10s')
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
