@@ -21,7 +21,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
-from smartcard.CardConnection import CardConnection
+from __future__ import print_function
 from smartcard.CardConnectionDecorator import CardConnectionDecorator
 from smartcard.Exceptions import CardConnectionException
 from smartcard.scard import SCardConnect, SCardDisconnect
@@ -64,7 +64,7 @@ class ExclusiveConnectCardConnection(CardConnectionDecorator):
                     raise CardConnectionException(
                         'Failed to connect with SCARD_SHARE_EXCLUSIVE' +\
                         SCardGetErrorMessage(hresult))
-                # print 'reconnected exclusive'
+                # print('reconnected exclusive')
                 break
             if hasattr(component, 'component'):
                 component = component.component
