@@ -4,8 +4,6 @@ The smartcard utility module provides classes and functions to
 access smartcards and readers.
 
 __author__ = "gemalto http://www.gemalto.com"
-__date__ = "May 2010"
-__version__ = "1.6.14"
 
 Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
