@@ -22,6 +22,7 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 from smartcard.scard import *
 
 # constants defined in PC/SC v2 Part 10
@@ -100,10 +101,10 @@ PCSCv2_PART10_PROPERTY_wLcdMaxCharacters,
 
 # we already have:       Features['FEATURE_x'] = FEATURE_x
 # we will now also have: Features[FEATURE_x] = 'FEATURE_x'
-for k in Features.keys():
+for k in list(Features.keys()):
     Features[Features[k]] = k
 
-for k in Properties.keys():
+for k in list(Properties.keys()):
     Properties[Properties[k]] = k
 
 
@@ -227,23 +228,24 @@ def getTlvProperties(cardConnection, featureList=None, controlCode=None):
 
 if __name__ == '__main__':
     """Small sample illustrating the use of PCSCPart10."""
-    from smartcard.pcsc.PCSCReader import readers
-    cc = readers()[0].createConnection()
+    from smartcard.pcsc.PCSCReader import PCSCReader
+    cc = PCSCReader.readers()[0].createConnection()
     cc.connect(mode=SCARD_SHARE_DIRECT)
 
-    #print cc.control( CM_IOCTL_GET_FEATURE_REQUEST )
+    #print(cc.control(CM_IOCTL_GET_FEATURE_REQUEST))
     features = getFeatureRequest(cc)
-    print features
+    print(features)
 
-    print hasFeature(features, FEATURE_VERIFY_PIN_START)
-    print hasFeature(features, FEATURE_VERIFY_PIN_DIRECT)
+    print(hasFeature(features, FEATURE_VERIFY_PIN_START))
+    print(hasFeature(features, FEATURE_VERIFY_PIN_DIRECT))
 
     properties = getPinProperties(cc)
-    print "\nPinProperties:"
-    for k in properties.keys():
-        print " %s: %s" % (k, properties[k])
+    print("\nPinProperties:")
+    for k, v in list(properties.items()):
+        print(" %s: %s" % (k, v))
 
-    print "\nTlvProperties:"
+    print("\nTlvProperties:")
     properties = getTlvProperties(cc)
-    for k in properties.keys():
-        print " %s: %s" % (k, properties[k])
+    for k, v in list(properties.items()):
+        print(" %s: %s" % (k, v))
+
