@@ -1,4 +1,4 @@
-/*==============================================================================
+/*===========================================================================
 Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
@@ -17,7 +17,7 @@ GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-==============================================================================*/
+===========================================================================*/
 #ifdef WIN32
     #include <windows.h>
 #endif
@@ -55,10 +55,10 @@ extern PyObject* PyExc_SCardError;
 #endif
 
 
-/**==========================================================================**/
+/**=======================================================================**/
 static int _IsAReaderState( PyObject* o)
-/*==============================================================================
-==============================================================================*/
+/*===========================================================================
+===========================================================================*/
 {
     PyObject* o2;
 
@@ -93,10 +93,10 @@ static int _IsAReaderState( PyObject* o)
     return 1;
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 static int _ReaderStateFromTuple( PyObject* o, READERSTATELIST* prl, unsigned int x )
-/*==============================================================================
-==============================================================================*/
+/*===========================================================================
+===========================================================================*/
 {
     char* psz;
     PyObject* o2;
@@ -115,8 +115,6 @@ static int _ReaderStateFromTuple( PyObject* o, READERSTATELIST* prl, unsigned in
         psz = PyBytes_AsString(temp_bytes); // Borrowed pointer
         if (NULL == psz)
             return 0;
-        psz = strdup(psz);
-        Py_DECREF(temp_bytes);
     }
     else
         return 0;
@@ -133,6 +131,10 @@ static int _ReaderStateFromTuple( PyObject* o, READERSTATELIST* prl, unsigned in
     prl->ars[x].szReader = prl->aszReaderNames[x];
     strcpy( prl->aszReaderNames[x], psz );
 
+#if PY_MAJOR_VERSION >= 3
+    Py_DECREF(temp_bytes);
+#endif
+
     // second tuple item is current state
     o2=PyTuple_GetItem(o, 1);
     prl->ars[x].dwCurrentState = (SCARDDWORDARG)PyInt_AsLong(o2);
@@ -157,16 +159,16 @@ static int _ReaderStateFromTuple( PyObject* o, READERSTATELIST* prl, unsigned in
 }
 
 
-/**=============================================================================
+/**==========================================================================
                             BYTELIST Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendByteListToPyObject(
     BYTELIST* source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 builds a Python list from a byte list
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* oByteList;
 
@@ -213,11 +215,11 @@ builds a Python list from a byte list
 }
 
 
-/**==========================================================================**/
+/**=======================================================================**/
 BYTELIST* SCardHelper_PyByteListToBYTELIST(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a Python byte list from a BYTELIST
-==============================================================================*/
+===========================================================================*/
 {
     Py_ssize_t cBytes, x;
     BYTELIST* pbl;
@@ -275,11 +277,11 @@ build a Python byte list from a BYTELIST
     return (BYTELIST*)pbl;
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_PrintByteList( BYTELIST* apsz )
-/*==============================================================================
+/*===========================================================================
 dump a byte list
-==============================================================================*/
+===========================================================================*/
 {
     unsigned long i;
 
@@ -291,16 +293,16 @@ dump a byte list
 }
 
 
-/**=============================================================================
+/**==========================================================================
                             ERRORSTRING Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_OutErrorStringAsPyObject(
     ERRORSTRING* source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 Builds a Python string from an ERRORSTRING
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* pystr;
 
@@ -316,16 +318,16 @@ Builds a Python string from an ERRORSTRING
     }
 }
 
-/**=============================================================================
+/**==========================================================================
                             GUIDLIST Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendGuidListToPyObject(
     GUIDLIST* source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 build a Python GUID list from a C GUID list
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* oByte;
     PyObject* oGuildItem;
@@ -401,11 +403,11 @@ build a Python GUID list from a C GUID list
 
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 GUIDLIST* SCardHelper_PyGuidListToGUIDLIST(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a Python byte list from a GUIDLIST
-==============================================================================*/
+===========================================================================*/
 {
     Py_ssize_t cBytes, cGuids, x;
     //int iGuid, iByte;
@@ -497,11 +499,11 @@ build a Python byte list from a GUIDLIST
     return (GUIDLIST*)pgl;
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_PrintGuidList( GUIDLIST* apsz )
-/*==============================================================================
+/*===========================================================================
 dump a GUID list
-==============================================================================*/
+===========================================================================*/
 {
     unsigned long i, j;
 
@@ -517,15 +519,15 @@ dump a GUID list
 }
 
 
-/**=============================================================================
+/**==========================================================================
                             READERSTATELIST Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendReaderStateListToPyObject(
     READERSTATELIST* source, PyObject** ptarget )
-/*==============================================================================
-==============================================================================*/
+/*===========================================================================
+===========================================================================*/
 {
     PyObject* oRStateList;
     //PyObject* o;
@@ -594,11 +596,11 @@ void SCardHelper_AppendReaderStateListToPyObject(
     }
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 READERSTATELIST* SCardHelper_PyReaderStateListToREADERSTATELIST(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a READERSTATELIST from a Python list of reader states
-==============================================================================*/
+===========================================================================*/
 {
     SCARDDWORDARG cRStates, x;
     READERSTATELIST* prl;
@@ -675,11 +677,11 @@ build a READERSTATELIST from a Python list of reader states
     return (READERSTATELIST*)prl;
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_PrintReaderStateList( READERSTATELIST* prl )
-/*==============================================================================
+/*===========================================================================
 dump a reader state list
-==============================================================================*/
+===========================================================================*/
 {
     int i;
     SCARDDWORDARG j;
@@ -744,16 +746,16 @@ dump a reader state list
     }
 }
 
-/**=============================================================================
+/**==========================================================================
                             SCARDCONTEXT Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendSCardContextToPyObject(
     SCARDCONTEXT source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 builds a Python SCARDCONTEXT from a C SCARDCONTEXT
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* oScardContext;
 
@@ -788,11 +790,11 @@ builds a Python SCARDCONTEXT from a C SCARDCONTEXT
     }
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 SCARDCONTEXT SCardHelper_PyScardContextToSCARDCONTEXT(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a SCARDCONTEXT from a python SCARDCONTEXT
-==============================================================================*/
+===========================================================================*/
 {
     SCARDCONTEXT scRet=0;
 
@@ -814,16 +816,16 @@ build a SCARDCONTEXT from a python SCARDCONTEXT
 }
 
 
-/**=============================================================================
+/**==========================================================================
                             SCARDHANDLE Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendSCardHandleToPyObject(
     SCARDHANDLE source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 builds a Python SCARDHANDLE from a C SCARDHANDLE
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* oScardHandle;
 
@@ -858,11 +860,11 @@ builds a Python SCARDHANDLE from a C SCARDHANDLE
     }
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 SCARDCONTEXT SCardHelper_PyScardHandleToSCARDHANDLE(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a SCARDHANDLE from a python SCARDHANDLE
-==============================================================================*/
+===========================================================================*/
 {
     SCARDHANDLE scRet=0;
 
@@ -883,16 +885,16 @@ build a SCARDHANDLE from a python SCARDHANDLE
     return scRet;
 }
 
-/**=============================================================================
+/**==========================================================================
                             SCARDDWORDARG Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendSCardDwordArgToPyObject(
     SCARDDWORDARG source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 builds a Python SCARDDWORDARG from a C SCARDDWORDARG
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* oScardDword;
 
@@ -927,11 +929,11 @@ builds a Python SCARDDWORDARG from a C SCARDDWORDARG
     }
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 SCARDDWORDARG SCardHelper_PySCardDwordArgToSCARDDWORDARG(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a SCARDDWORDARG from a python SCARDDWORDARG
-==============================================================================*/
+===========================================================================*/
 {
     SCARDDWORDARG scRet=0;
 
@@ -953,16 +955,16 @@ build a SCARDDWORDARG from a python SCARDDWORDARG
 }
 
 
-/**=============================================================================
+/**==========================================================================
                             STRING Helpers
-==============================================================================*/
+===========================================================================*/
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendStringToPyObject(
     STRING* source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 Builds a Python string from a STRING
-==============================================================================*/
+===========================================================================*/
 {
     PyObject* pystr;
 
@@ -1010,12 +1012,12 @@ Builds a Python string from a STRING
     }
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 STRING* SCardHelper_PyStringToString( PyObject* source )
-/*==============================================================================
+/*===========================================================================
 Build a STRING from a Python string; the string is allocated and
 will have to be freed externally to the wrapper
-==============================================================================*/
+===========================================================================*/
 {
     size_t ulLength;
     STRING* pstr=NULL;
@@ -1051,11 +1053,11 @@ will have to be freed externally to the wrapper
     return pstr;
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_PrintString( STRING* str )
-/*==============================================================================
+/*===========================================================================
 dump a string list
-==============================================================================*/
+===========================================================================*/
 {
     if(NULL!=str)
     {
@@ -1067,19 +1069,19 @@ dump a string list
     }
 }
 
-/**=============================================================================
+/**==========================================================================
                             STRINGLIST Helpers
-==============================================================================*/
+===========================================================================*/
 
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_AppendStringListToPyObject(
     STRINGLIST* source, PyObject** ptarget )
-/*==============================================================================
+/*===========================================================================
 builds a Python list from a STRINGLIST; the multi-string list in the STRINGLIST
 is stored as series of null-terminated strings terminated by a null,
 e.g. item0\0item2\0lastitem\0\0)
-==============================================================================*/
+===========================================================================*/
 {
     unsigned int cStr;
     char* p=source->ac;
@@ -1156,11 +1158,11 @@ e.g. item0\0item2\0lastitem\0\0)
 
 }
 
-/**==========================================================================**/
+/**=======================================================================**/
 STRINGLIST* SCardHelper_PyStringListToStringList(PyObject* source)
-/*==============================================================================
+/*===========================================================================
 build a Python string list from a STRINGLIST
-==============================================================================*/
+===========================================================================*/
 {
     Py_ssize_t cStrings, cChars, x;
     STRINGLIST* psl;
@@ -1239,11 +1241,11 @@ build a Python string list from a STRINGLIST
 }
 
 
-/**==========================================================================**/
+/**=======================================================================**/
 void SCardHelper_PrintStringList( STRINGLIST* sl )
-/*==============================================================================
+/*===========================================================================
 dump a string list
-==============================================================================*/
+===========================================================================*/
 {
     char* p=(char*)sl->ac;
     unsigned int i;
@@ -1263,11 +1265,11 @@ dump a string list
 }
 
 #ifdef WIN32
-/**==========================================================================**/
+/**=======================================================================**/
 BOOL WINAPI DllMain( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved )
-/*==============================================================================
+/*===========================================================================
 Initialize and clean-up memory logging on process attach and detach
-==============================================================================*/
+===========================================================================*/
 {
     switch(fdwReason)
     {
