@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import unittest
 import string
 
@@ -39,8 +40,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -64,8 +65,8 @@ class testcase_CardConnection(unittest.TestCase):
                 cc.connect()
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "6e 0": 2, "9f 20": 3, "9f 22": 4}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
@@ -82,8 +83,8 @@ class testcase_CardConnection(unittest.TestCase):
                 cc.connect(CardConnection.T0_protocol)
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "6e 0": 2, "9f 20": 3, "9f 22": 4}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
@@ -94,17 +95,14 @@ class testcase_CardConnection(unittest.TestCase):
 
         for reader in readers():
             cc = reader.createConnection()
-            # on Mac OS X Tiger, trying to connect
-            # with T=1 protocol does not except
-            if not 'pcsclite-tiger' == resourceManagerSubType:
-                if [] != expectedATRinReader[str(reader)]:
-                    # should fail since the test card does not support T1
-                    self.assertRaises(
-                        CardConnectionException,
-                        cc.connect,
-                        CardConnection.T1_protocol)
-                else:
-                    self.assertRaises(NoCardException, cc.connect)
+            if [] != expectedATRinReader[str(reader)]:
+                # should fail since the test card does not support T1
+                self.assertRaises(
+                    CardConnectionException,
+                    cc.connect,
+                    CardConnection.T1_protocol)
+            else:
+                self.assertRaises(NoCardException, cc.connect)
         cc.disconnect()
 
     def testcase_CardConnectionT1inTransmit(self):
@@ -137,8 +135,8 @@ class testcase_CardConnection(unittest.TestCase):
                     CardConnection.T0_protocol | CardConnection.T1_protocol)
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "6e 0": 2, "9f 20": 3, "9f 22": 4}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
@@ -156,8 +154,8 @@ class testcase_CardConnection(unittest.TestCase):
                 response, sw1, sw2 = cc.transmit(
                     SELECT + DF_TELECOM, CardConnection.T0_protocol)
                 expectedSWs = {"9f 1a": 1, "6e 0": 2, "9f 20": 3, "9f 22": 4}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
