@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import threading
 import unittest
 import time
@@ -41,8 +42,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -57,14 +58,15 @@ class printobserver(CardObserver):
         self.obsindex = obsindex
         self.testcase = testcase
 
-    def update(self, observable, (addedcards, removedcards)):
+    def update(self, observable, actions):
+        (addedcards, removedcards) = actions
         foundcards = {}
-        self.testcase.assertEquals(removedcards, [])
+        self.testcase.assertEqual(removedcards, [])
         for card in addedcards:
             foundcards[toHexString(card.atr)] = 1
         for atr in expectedATRs:
             if [] != atr and {} != foundcards:
-                self.testcase.assert_(toHexString(atr) in foundcards)
+                self.testcase.assertTrue(toHexString(atr) in foundcards)
 
 
 class testthread(threading.Thread):
